summary refs log tree commit diff stats
path: root/plugins/fishlim/plugin_hexchat.c
diff options
context:
space:
mode:
authorBerke Viktor <bviktor@hexchat.org>2012-10-30 11:47:12 +0100
committerBerke Viktor <bviktor@hexchat.org>2012-10-30 11:47:12 +0100
commit507af191bd9a100656b70da66111e2af105d82ee (patch)
tree8c7c87b06471746ad5282d962bd51ab0cec996b9 /plugins/fishlim/plugin_hexchat.c
parenta51a69134b8bdc94cfb4dcc1403e33cce24d34bc (diff)
Now some final cleanup (I hope)
Diffstat (limited to 'plugins/fishlim/plugin_hexchat.c')
-rw-r--r--plugins/fishlim/plugin_hexchat.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/plugins/fishlim/plugin_hexchat.c b/plugins/fishlim/plugin_hexchat.c
index 0f635cd9..3401f25d 100644
--- a/plugins/fishlim/plugin_hexchat.c
+++ b/plugins/fishlim/plugin_hexchat.c
@@ -28,7 +28,7 @@
 
 // #pragma GCC visibility push(default)
 #include "hexchat-plugin.h"
-#define XCHAT_MAX_WORDS 32
+#define HEXCHAT_MAX_WORDS 32
 // #pragma GCC visibility pop
 
 //#define EXPORT __attribute((visibility("default")))
@@ -127,7 +127,7 @@ static int handle_incoming(char *word[], char *word_eol[], void *userdata) {
     if (!strcmp(command, "332")) w++;
     
     // Look for encrypted data
-    for (ew = w+1; ew < XCHAT_MAX_WORDS-1; ew++) {
+    for (ew = w+1; ew < HEXCHAT_MAX_WORDS-1; ew++) {
         const char *s = (ew == w+1 ? word[ew]+1 : word[ew]);
         if (strcmp(s, "+OK") == 0 || strcmp(s, "mcps") == 0) goto has_encrypted_data;
     }
@@ -150,7 +150,7 @@ static int handle_incoming(char *word[], char *word_eol[], void *userdata) {
     length = 0;
     if (!append(&message, &length, "RECV")) goto decrypt_error;
     
-    for (uw = 1; uw < XCHAT_MAX_WORDS; uw++) {
+    for (uw = 1; uw < HEXCHAT_MAX_WORDS; uw++) {
         if (word[uw][0] != '\0' && !append(&message, &length, " ")) goto decrypt_error;
         
         if (uw == ew) {
@@ -263,7 +263,7 @@ int hexchat_plugin_init(hexchat_plugin *plugin_handle,
                       char *arg) {
     ph = plugin_handle;
     
     /* Send our info to XChat */
     *name = plugin_name;
     *desc = plugin_desc;
     *version = plugin_version;
@@ -263,7 +263,7 @@ int hexchat_plugin_init(hexchat_plugin *plugin_handle,
     ph = plugin_handle;
     
-    /* Send our info to XChat */
+    /* Send our info to HexChat */
     *name = plugin_name;
     *desc = plugin_desc;